﻿using System;
using System.Drawing;
using System.Text.RegularExpressions;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 축 1
        /// </summary>
        private Axis axis1;

        /// <summary>
        /// 축 2
        /// </summary>
        private Axis axis2;

        /// <summary>
        /// 캔들 시리즈
        /// </summary>
        private Candle candle;

        /// <summary>
        /// CCI 함수
        /// </summary>
        private CCIFunction cciFunction;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 축 1을 생성한다.

            this.axis1 = new Axis();

            this.axis1.StartPosition = 0;
            this.axis1.EndPosition   = 49;
            this.axis1.MaximumOffset = 5;
            this.axis1.MinimumOffset = 5;

            #endregion
            #region 축 2를 생성한다.

            this.axis2 = new Axis();

            this.axis2.StartPosition = 51;
            this.axis2.EndPosition   = 100;

            #endregion

            #region 캔들 시리즈를 생성한다.

            this.candle = new Candle();

            this.candle.Title          = "candle";
            this.candle.VertAxis       = VerticalAxis.Custom;
            this.candle.CustomVertAxis = this.axis1;

            this.candle.FillSampleValues();

            #endregion
            #region CCI 함수를 생성한다.

            this.cciFunction = new CCIFunction();

            this.cciFunction.Period = 20;

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title          = "line";
            this.line.VertAxis       = VerticalAxis.Custom;
            this.line.CustomVertAxis = this.axis2;
            this.line.Brush.Color    = Color.FromArgb(90, 150, 220);
            this.line.Color          = Color.FromArgb(90, 150, 220);
            this.line.DataSource     = this.candle;
            this.line.Function       = this.cciFunction;

            #endregion

            #region 티차트를 설정한다.

            this.tChart.Panel.MarginLeft  = 5;
            this.tChart.Legend.Visible    = false;
            this.tChart.Axes.Left.Visible = false;

            this.tChart.Axes.Custom.Add(this.axis1);
            this.tChart.Axes.Custom.Add(this.axis2);

            this.tChart.Series.Add(this.candle);
            this.tChart.Series.Add(this.line);

            #endregion

            this.movingAveragePeriodNumericUpDown.Value = (decimal)cciFunction.Period;

            this.constantTextBox.Text = cciFunction.Constant.ToString();

            this.movingAveragePeriodNumericUpDown.ValueChanged += movingAveragePeriodNumericUpDown_ValueChanged;
            this.constantTextBox.TextChanged                   += constantTextBox_TextChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 이동 평균 기간 숫자 UP/DOWN 값 변경시 처리하기 - movingAveragePeriodNumericUpDown_ValueChanged(sender, e)

        /// <summary>
        /// 이동 평균 기간 숫자 UP/DOWN 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void movingAveragePeriodNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            this.cciFunction.Period = (double)this.movingAveragePeriodNumericUpDown.Value;
        }

        #endregion
        #region 상수 텍스트 박스 텍스트 변경시 처리하기 - constantTextBox_TextChanged(sender, e)

        /// <summary>
        /// 상수 텍스트 박스 텍스트 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void constantTextBox_TextChanged(object sender, EventArgs e)
        {
            if(!Regex.IsMatch(this.constantTextBox.Text, @"[^0-9.,]") && this.constantTextBox.Text != string.Empty)
            {
                try
                {
                    this.cciFunction.Constant = Convert.ToDouble(this.constantTextBox.Text);
                }
                catch
                {
                    throw;
                }
            }
        }

        #endregion
    }
}